.. role:: hidden
    :class: hidden-section

ax.metrics
==========

.. automodule:: ax.metrics
.. currentmodule:: ax.metrics


BoTorch Test Problem
~~~~~~~~~~~~~~~~~~~~

.. automodule:: ax.metrics.botorch_test_problem
    :members:
    :undoc-members:
    :show-inheritance:

Branin
~~~~~~

.. automodule:: ax.metrics.branin
    :members:
    :undoc-members:
    :show-inheritance:

Branin Map
~~~~~~~~~~

.. automodule:: ax.metrics.branin_map
    :members:
    :undoc-members:
    :show-inheritance:

Chemistry
~~~~~~~~~

.. automodule:: ax.metrics.chemistry
    :members:
    :undoc-members:
    :show-inheritance:

Curve
~~~~~

.. automodule:: ax.metrics.curve
    :members:
    :undoc-members:
    :show-inheritance:

Dictionary Lookup
~~~~~~~~~~~~~~~~~

.. automodule:: ax.metrics.dict_lookup
    :members:
    :undoc-members:
    :show-inheritance:

Factorial
~~~~~~~~~

.. automodule:: ax.metrics.factorial
    :members:
    :undoc-members:
    :show-inheritance:

Hartmann6
~~~~~~~~~

.. automodule:: ax.metrics.hartmann6
    :members:
    :undoc-members:
    :show-inheritance:

Jenatton
~~~~~~~~

.. automodule:: ax.metrics.jenatton
    :members:
    :undoc-members:
    :show-inheritance:


L2 Norm
~~~~~~~

.. automodule:: ax.metrics.l2norm
    :members:
    :undoc-members:
    :show-inheritance:

Noisy Functions
~~~~~~~~~~~~~~~

.. automodule:: ax.metrics.noisy_function
    :members:
    :undoc-members:
    :show-inheritance:

Noisy Function Map
~~~~~~~~~~~~~~~~~~

.. automodule:: ax.metrics.noisy_function_map
    :members:
    :undoc-members:
    :show-inheritance:

Sklearn
~~~~~~~

.. automodule:: ax.metrics.sklearn
    :members:
    :undoc-members:
    :show-inheritance:

Tensorboard
~~~~~~~~~~~

.. automodule:: ax.metrics.tensorboard
    :members:
    :undoc-members:
    :show-inheritance:


TorchX
~~~~~~

.. automodule:: ax.metrics.torchx
    :members:
    :undoc-members:
    :show-inheritance:
